@@ -64,12 +64,15 @@ class App(tornado.web.Application):
         self.api_docs = kwargs.get("api_docs", {})
         self.docs_dir = self.get_path(self.api_docs.get("docs_dir", "docs"))
         self.jinja2_path_dir = kwargs.get("jinja2_dir", "jinja2")
-
+        self.socket_setting = kwargs.get("socket", {})
         self.cookie_secret = kwargs.get("cookie_secret", "f465ca164f0e")
         self.settings = dict(debug=self.debug,
                              template_path=self.template_path,
                              static_path=self.static_path,
-                             cookie_secret=self.cookie_secret)
+                             cookie_secret=self.cookie_secret,
+                             websocket_ping_interval=self.socket_setting.get("websocket_ping_interval", 5),
+                             websocket_ping_timeout=self.socket_setting.get("websocket_ping_timeout", None),
+                             )
 
         self.log_config = self.kwargs.get("logging_config", {})
         self.init_log()
@@ -80,7 +83,7 @@ class App(tornado.web.Application):
         self.impmodule()
         self.handlers = route.get_routes(self.ROOT, self.handler_dir)
         # self.handlers.append((r'/docs', DocsHandler))
-        self.handlers.append(tornado.web.url(r'/docs', DocsHandler, name=DocsHandler.__name__))
+        self.handlers.append(tornado.web.url(r'/docs/', DocsHandler, name=DocsHandler.__name__))
         self.handlers.append(tornado.web.url(r'/.*', BaseHandler, name=BaseHandler.__name__))
         if not self.handlers:
             raise Exception("no api handler has been register.")
@@ -235,9 +238,9 @@ class App(tornado.web.Application):
         tornado.options.define(name="app_config", default=self.kwargs, help='App server config', type=str)
         http_server = tornado.httpserver.HTTPServer(self, max_buffer_size=self.max_buffer_size, xheaders=True)
         http_server.bind(self.port)
-        logging.warning("Server Config file: " + self.kwargs["config_name"])
-        logging.warning("Server ROOT path: " + self.ROOT)
-        logging.warning('Server Running on http://%s:%s' % (self.uri, self.port))
+        logging.warning("Server Config File: " + self.kwargs["config_name"])
+        logging.warning("Server Root Path: " + self.ROOT)
+        logging.warning('Server Running On http://%s:%s' % (self.uri, self.port))
         if platform.system() == "Windows":
             asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
         http_server.start()
