@@ -36,6 +36,8 @@ class BaseHandler(RequestHandler):
     emchat = None
     aes = None
     graylog = None
+    sms = None
+    smtp = None
 
     def __init__(self, application, request, **kwargs):
         self.application = application
@@ -109,7 +111,7 @@ class BaseHandler(RequestHandler):
                 logging.error("异常信息：" + error.message)
 
             logging.error("请求地址: %s %.2fms", self.request.uri, 1000.0 * self.request.request_time())
-            logging.error("请求参数: " + (json.dumps(utils.pparams(self.request, self.params), ensure_ascii=False) if hasattr(self, "params") else str(utils.pparams(self.request, self.request.arguments) or {})))
+            logging.error("请求参数: " + (json.dumps(utils.check2json(utils.pparams(self.request, params=self.params))) if hasattr(self, "params") else str(utils.pparams(self.request) or {})))
             if not hasattr(error, "code_name") or not hasattr(error, "code"):
                 return self.write_failed()
             else:
@@ -127,14 +129,14 @@ class BaseHandler(RequestHandler):
         if hasattr(self, "graylog") and self.graylog:
             if self.application.app_config["graylog_config"].get("mode", 0) or is_slow_request:
                 self.graylog.from_server(short_message="OK", code=0, host=self.request.host, request_time=int(request_time), remote_ip=self.request.remote_ip,
-                                         uri=self.request.path, params=utils.pparams(self.request, p), method=self.request.method)
+                                         uri=self.request.path, params=utils.pparams(self.request, params=p), method=self.request.method)
         return self.write({"code": 0, "msg": "OK", "data": get_return(self, data or {})})
 
     def write_failed(self, code=1, msg="Error. unknown error", name="HTTP 500"):
         if hasattr(self, "graylog") and self.graylog:
             p = self.params if hasattr(self, "params") else {}
             self.graylog.from_server(short_message=msg, code=code, track=format_exc()[-500:], host=self.request.host, header=self.request.headers._dict,
-                                     remote_ip=self.request.remote_ip, uri=self.request.path, params=utils.pparams(self.request, p), method=self.request.method)
+                                     remote_ip=self.request.remote_ip, uri=self.request.path, params=utils.pparams(self.request, params=p), method=self.request.method)
         if name:
             self.write({"code": code, "msg": msg, "name": name, "data": None})
             return
@@ -251,7 +253,9 @@ class BaseModel(object):
     emchat = None
     aes = None
     graylog = None
-
+    sms = None
+    smtp = None
+    
     @classmethod
     def _parse_data(cls, d, **kwargs):
         """
@@ -511,7 +515,7 @@ class BaseSchema(object):
         return cls._parse_data(cls.__parse_oid(d)) if d else {}
 
     @classmethod
-    def find(cls, spec=None, fields=False, limit=False, skip=False, sort=False, is_cursor=False, shard_key_value=None):
+    def find(cls, spec=None, fields=False, limit=False, skip=False, sort=False, is_cursor=False, shard_key_value=None, **kwargs):
         """
         fields: {"uid": 1}
         limit: 10
@@ -521,27 +525,13 @@ class BaseSchema(object):
         :param cursor:  True 返回游标，否则返回list
         :return:
         """
-        spec = cls.__check_id(spec)
-        data = []
-        spec = spec or {}
-        if type(sort) == dict:
-            sort = list(sort.items())
-        if fields and isinstance(fields, dict):
-            cursor = cls.dbo(sql=spec, shard_key_value=shard_key_value).find(spec, fields)
+        cursor = cls.__find(spec, fields, limit, skip, sort, is_cursor, shard_key_value)
+        if not is_cursor:
+            data_list = [cls._parse_data(cls.__parse_oid(d), **kwargs) for d in cursor if d]
+            return data_list
+            # return data_list, total_page, cursor.count()
         else:
-            cursor = cls.dbo(sql=spec, shard_key_value=shard_key_value).find(spec)
-
-        if limit is not False:
-            cursor = cursor.limit(int(limit))
-        if skip is not False:
-            cursor = cursor.skip(int(skip))
-        if sort is not False:
-            cursor = cursor.sort(sort)
-
-        if is_cursor:
             return cursor
-        else:
-            return list(cursor)
 
     @classmethod
     def distinct(cls, distinct, spec, shard_key_value=None, **kwargs):
@@ -569,7 +559,7 @@ class BaseSchema(object):
         """
         spec = cls.__check_id(spec)
         if not kwargs:  # 利用cursor游标
-            result = cls.find(spec, is_cursor=True, shard_key_value=shard_key_value).distinct(distinct)
+            result = cls.__find(spec, is_cursor=True, shard_key_value=shard_key_value).distinct(distinct)
         else:
             result = cls.dbo(shard_key_value=shard_key_value).distinct(key=distinct, filter=spec, **kwargs)
 
@@ -673,7 +663,7 @@ class BaseSchema(object):
                                                                                sort=kwargs.pop("sort", None),
                                                                                full_response=kwargs.pop("full_response", False),
                                                                                manipulate=kwargs.pop("manipulate", False), **kwargs)
-        return cls._parse_data(cls.__parse_oid(d)) if d else {}
+        return cls._parse_data(cls.__parse_oid(d), **kwargs) if d else {}
 
     @classmethod
     def find_one_and_replace(cls, spec, docs, shard_key_value=None, **kwargs):
@@ -699,7 +689,7 @@ class BaseSchema(object):
             kwargs["sort"] = list(sort.items())
         kwargs.setdefault("return_document", True)
         d = cls.dbo(sql=spec, shard_key_value=shard_key_value).find_one_and_replace(spec, docs, **kwargs)
-        return cls._parse_data(cls.__parse_oid(d)) if d else {}
+        return cls._parse_data(cls.__parse_oid(d), **kwargs) if d else {}
 
     @classmethod
     def find_one_and_update(cls, spec, docs, shard_key_value=None, **kwargs):
@@ -730,7 +720,7 @@ class BaseSchema(object):
             kwargs["sort"] = list(sort.items())
         docs.setdefault("$set", {})['update_at'] = utils.now()
         d = cls.dbo(sql=spec, shard_key_value=shard_key_value).find_one_and_update(spec, docs, **kwargs)
-        return cls._parse_data(cls.__parse_oid(d)) if d else {}
+        return cls._parse_data(cls.__parse_oid(d), **kwargs) if d else {}
 
     @classmethod
     def find_one_and_delete(cls, spec, shard_key_value=None, **kwargs):
@@ -758,10 +748,10 @@ class BaseSchema(object):
         if sort and type(sort) == dict:
             kwargs["sort"] = list(sort.items())
         d = cls.dbo(sql=spec, shard_key_value=shard_key_value).find_one_and_delete(spec, **kwargs)
-        return cls._parse_data(cls.__parse_oid(d)) if d else {}
+        return cls._parse_data(cls.__parse_oid(d), **kwargs) if d else {}
 
     @classmethod
-    def find_list_by_page(cls, spec, page, count=10, sort={"create_at": -1}, fields=False, shard_key_value=None):
+    def find_list_by_page(cls, spec, page, count=10, sort={"create_at": -1}, fields=False, shard_key_value=None, **kwargs):
         """
         按照count分页，返回当前页数据和总页数
         :param spec:
@@ -769,13 +759,13 @@ class BaseSchema(object):
         :param sort: must be obj like [("a", -1), ...]
         :return:
         """
-        cursor = cls.find(spec, fields=fields, is_cursor=True, shard_key_value=shard_key_value)
-        data_list = [cls._parse_data(cls.__parse_oid(d)) for d in list(cls.__meta_cursor(cursor, page, count, sort)) if d]
+        cursor = cls.__find(spec, fields=fields, is_cursor=True, shard_key_value=shard_key_value)
+        data_list = [cls._parse_data(cls.__parse_oid(d), **kwargs) for d in list(cls.__meta_cursor(cursor, page, count, sort)) if d]
         total_page = cls.__get_total_page(cursor, count)
         return data_list, total_page, cursor.count()
 
     @classmethod
-    def find_list_by_last_id(cls, spec, count=10, sort={"create_at": -1}, fields=False, last_id_field=False, shard_key_value=None):
+    def find_list_by_last_id(cls, spec, count=10, sort={"create_at": -1}, fields=False, last_id_field=False, shard_key_value=None, **kwargs):
         """
         list by last_id
         :param spec:
@@ -783,8 +773,8 @@ class BaseSchema(object):
         :param sort: must be obj like [("a", -1), ...]
         :return:
         """
-        cursor = cls.find(spec, fields=fields, is_cursor=True, shard_key_value=shard_key_value)
-        data_list = [cls._parse_data(cls.__parse_oid(d)) for d in list(cls.__meta_cursor(cursor, count=count, sort=sort)) if d]
+        cursor = cls.__find(spec, fields=fields, is_cursor=True, shard_key_value=shard_key_value)
+        data_list = [cls._parse_data(cls.__parse_oid(d), **kwargs) for d in list(cls.__meta_cursor(cursor, count=count, sort=sort)) if d]
         last_id_field = last_id_field if last_id_field else "create_at"
         last_id = data_list[-1][last_id_field] - 1 if data_list else -1
         return data_list, last_id
@@ -807,8 +797,11 @@ class BaseSchema(object):
         count = kwargs.get("count", 0)
         sort = kwargs.get("sort", {"create_at": -1})
 
-        cursor = cls.find({key: {"$in": vals}}, fields=fields, is_cursor=True, shard_key_value=shard_key_value)
-        data = [cls.__parse_oid(d) for d in list(cls.__meta_cursor(cursor, 0, 0, sort)) if d]
+        if vals:
+            cursor = cls.__find({key: {"$in": vals}}, fields=fields, is_cursor=True, shard_key_value=shard_key_value)
+            data = [cls.__parse_oid(d) for d in list(cls.__meta_cursor(cursor, 0, 0, sort)) if d]
+        else:
+            data = []
 
         for d in data:
             tmp = {}
@@ -821,7 +814,7 @@ class BaseSchema(object):
                 tmp = d
             data_mp[d[key]] = tmp
 
-        return {k: cls._parse_data(v) for k, v in data_mp.items()}
+        return {k: cls._parse_data(v, **kwargs) for k, v in data_mp.items()}
 
     @classmethod
     def next_seq_id(cls, seq_name="seq_id", val=0, random_step=10):
@@ -838,6 +831,38 @@ class BaseSchema(object):
             return result['val']
         return None
 
+    @classmethod
+    def __find(cls, spec=None, fields=False, limit=False, skip=False, sort=False, is_cursor=False, shard_key_value=None, **kwargs):
+        """
+        fields: {"uid": 1}
+        limit: 10
+        skip: 10
+        sort: {"uid": -1}
+        :param spec:
+        :param cursor:  True 返回游标，否则返回list
+        :return:
+        """
+        spec = cls.__check_id(spec)
+        spec = spec or {}
+        if type(sort) == dict:
+            sort = list(sort.items())
+        if fields and isinstance(fields, dict):
+            cursor = cls.dbo(sql=spec, shard_key_value=shard_key_value).find(spec, fields)
+        else:
+            cursor = cls.dbo(sql=spec, shard_key_value=shard_key_value).find(spec)
+
+        if limit is not False:
+            cursor = cursor.limit(int(limit))
+        if skip is not False:
+            cursor = cursor.skip(int(skip))
+        if sort is not False:
+            cursor = cursor.sort(sort)
+
+        if is_cursor:
+            return cursor
+        else:
+            return list(cursor)
+
     @classmethod
     def _parse_data(cls, d, **kwargs):
         """
