@@ -11,7 +11,7 @@ config = InitContext.get_context()
 # InitContext.init_db()
 
 config["api_schema"] = yaml2py.load_api_schema("api_schema")
-config["wsgi"]["port"] = config["wsgi"]["port"] if len(sys.argv) == 1 else int(sys.argv[1])
+# config["wsgi"]["port"] = config["wsgi"]["port"] if len(sys.argv) == 1 else int(sys.argv[1])
 # config["mqtt_config"]["client_id_name"] = "app_%s_%s" % (platform.node(), config["wsgi"]["port"])
 
 app = App(**config)
