@@ -27,7 +27,8 @@ class DemoHandler(BaseHandler):
         :return:
         :rtype:
         """
-
+        # 上传文件 self.request.files = {'excel': [{'filename': 'xxxxxxx.xlsx', 'body':"xxxxxx"}]
+        excel = self.params["excel"]  # {'filename': 'xxxxxxx.xlsx', 'body':"xxxxxx"}
 
         self.write_success()
         
@@ -46,6 +47,23 @@ class DemoHandler(BaseHandler):
         :return:
         :rtype:
         """
+        # 发送邮件
+        self.smtp.send_email(
+            ["452809783@qq.com", "123220663@qq.com"],
+            "邮件标题6",
+            message="文本",
+            html_message="""
+                <p style="color:red">邮件文本内容</p>
+                <p><a href="http://www.xxx.com">链接</a></p>
+                <p>内容中的图片未被显示时，需添加发件人信任。或者点击邮件页面中的"显示图片 信任此发件人的图片"</p>
+                <p><img src="https://www.runoob.com/wp-content/uploads/2016/04/smtp4.jpg"></p>
+                <p>图片标签：以下需添加image1的标签图片</p>
+                <p><img src="cid:image1"></p>
+                <p>2222</p>
+                """,
+            images=["/Users/apple/Downloads/WX20220714-160954@2x.png"],
+            attachs=["/Users/apple/Downloads/WX20220714-154222@2x.png"]
+        )
         # redis
         # self.redis.set("a", 1)
         # self.redis.get("a")
@@ -84,10 +102,9 @@ class DemoHandler(BaseHandler):
         # self.graylog.from_server(x="sdsdds")
         # 调用model，创建一条用户数据
 
-        # self.model.DemoModel.create_demo()
-
-        data = {"a": "山东省地方"}
-        self.write_success(data)
+        self.model.DemoModel.get_demo(1)
+        self.websocket.Events.demo(**{"a": 1, "b": 2})
+        self.write_success()
 
 
 
