@@ -12,6 +12,7 @@ class DemoModel(BaseModel, DemoSchema):
         :return:
         :rtype:
         """
+        cls.mysql.insert(cls.collection, {"name": 3}, new=True)
         # 获取当前表所有字段
         fields = DemoSchema.fields()
 
@@ -74,6 +75,10 @@ class DemoModel(BaseModel, DemoSchema):
         # cls.mysql.insert(cls.collection, [{"name": 2}, {"name": 3}])
         # data = cls.mysql.query_sql(sql="select * from demo where name=(name)", params={"name": 2})
         # data = cls.mysql.query_sql(sql="select * from demo where name=%s", params=[2, ])
+        # data = cls.mysql.insert(cls.collection, {"name": 3}, new=True)
+        # data = cls.mysql.insert(cls.collection, [{"name": 3}], new=True)
+        # datas = cls.mysql.inserts(cls.collection, [{"name": 2}, {"name": 3}], new=True)
+
         return cls._parse_data(fields)
 
 
