@@ -7,7 +7,7 @@ from context import InitContext
 from lcyframe.libs.singleton import MongoCon
 from lcyframe.libs.cprint import cprint
 from lcyframe.libs.JWT import JwtToken
-import requests
+from utils import helper
 
 config = InitContext.get_context()
 db = MongoCon().get_database(**config["mongo_config"])
@@ -63,7 +63,10 @@ def admin_login_and_send(methed, url, params, **kwargs):
         _url = config["wsgi"]["host"] + ":" + str(config["wsgi"]["port"])
     _url += url
 
-
+    try:
+        import requests
+    except:
+        raise Exception("请导入requests请求库")
     if methed == "delete":
         kwargs["data"] = params
         data = eval("requests.%s" % methed)(_url, **kwargs)
