@@ -1,14 +1,14 @@
 # coding=utf-8
-import os
+import os, re
 import logging
 import random
 import time
 from datetime import datetime, date
-import zlib, hmac, urllib
+import zlib, hmac
 from bson import BSON, ObjectId
 from functools import wraps
 from lcyframe.libs import utils, funts, cprint, JWT, aes, Rsa, errors
-import re
+from utils import errors
 
 
 def get_excel_url(host, img, path=None):
@@ -36,15 +36,14 @@ def get_imge_url(host, img, path=None):
     else:
         host = "http://" + host
 
-    safe_params = os.path.join(path, img)
-    p = os.path.join(host, urllib.parse.quote(safe_params, safe='/', encoding=None, errors=None))
+    p = os.path.join(host, path, img)
     return p
 
 
 def save_filedata(data, base_path, **kwargs):
     """保存文件"""
     if not data:
-        return ""
+        return "", ""
 
     filename = gen_filename(data, **kwargs)
     save_path = gen_filepath(base_path, filename)
@@ -54,10 +53,12 @@ def save_filedata(data, base_path, **kwargs):
 
     if not os.path.exists(save_path):
         with open(save_path, "wb") as f:
-            f.write(data["body"])
+            body = data["body"] if isinstance(data["body"], bytes) else data["body"].encode("u8")
+            f.write(body)
 
     return filename, save_path
 
+
 def gen_filepath(base_path, filename=None):
     if not os.path.exists("%s" % base_path):
         os.makedirs("%s" % base_path)
@@ -65,7 +66,8 @@ def gen_filepath(base_path, filename=None):
     save_path = "%s/%s" % (base_path, filename)
     return save_path
 
-def gen_filename(file_data, prefix="", suffix="", name_type="unique"):
+
+def gen_filename(file_data, prefix="", suffix="", name_type="unique", require_format=[], require_size=0):
     """
     生成文件名
     根据数据md5对文件去重
@@ -74,7 +76,8 @@ def gen_filename(file_data, prefix="", suffix="", name_type="unique"):
     :return:
 
     """
-    metadata = get_fileinfo(file_data)
+
+    metadata = get_fileinfo(file_data, require_format=require_format, require_size=require_size)
 
     if name_type == "unique":
         filename = metadata["unique_name"]
@@ -85,18 +88,37 @@ def gen_filename(file_data, prefix="", suffix="", name_type="unique"):
     else:
         filename = metadata["name"]
 
-    return "%s%s%s.%s" % (prefix, filename, suffix, metadata["format"])
+    if metadata["format"]:
+        return "%s%s%s.%s" % (prefix, filename, suffix, metadata["format"])
+    else:
+        return "%s%s%s" % (prefix, filename, suffix)
 
-def get_fileinfo(file_data=None, file_path=None):
+
+def get_fileinfo(file_data=None, file_path=None, require_format=[], require_size=0):
     """
     读取文件基本信息
     :param file_data:
     :return:
     """
     if file_data:
+        if not isinstance(file_data, dict):
+            file_data = {
+                "body": file_data,
+                "filename": "default"
+            }
         body = file_data["body"]
-        unique_name = utils.md5(body)
-        name, format = file_data["filename"].split(".")
+        filename = file_data["filename"]
+        unique_name = utils.md5(body if isinstance(body, bytes) else body.encode("u8"))
+        name, format = file_data["filename"].rsplit(".", 1) if "." in file_data["filename"] else (
+        file_data["filename"], "")
+        # TODO Fix 包含有以下几种符号的文件名，会导致系统解压命令失败：'('、')'。如需在线调用系统命令解压，请打开注释.
+        #  推荐使用python的Patool库进行统一加解压，可避免此问题
+        # if format in ["rar", "zip", "pkg", "gz", "tar", "jar", "7z"]:
+        #     if name.find("(") or name.find(")"):
+        #         name = name.replace("(", "（").replace(")", "）")
+        #
+        #     filename = name + "." + format if format else name
+
         size = len(body)
     elif file_path and os.path.exists(file_path):
         with open(file_path, "r") as p:
@@ -107,21 +129,28 @@ def get_fileinfo(file_data=None, file_path=None):
     else:
         raise
 
+    if require_format and format.lower() not in require_format:
+        raise errors.UploadError("请上传指定格式：" + ",".join(require_format))
+    if require_size and size > require_size:
+        raise errors.UploadError("大小不能超过%sM" % int(require_size / 1024 / 1024))
+
     return {
-        "filename": file_data["filename"],
+        "filename": filename,
         "name": name,
-        "format": format,
+        "format": format.lower(),
         "size": size,
         "unique_name": unique_name,
-        "unique_filename": "%s.%s" % (unique_name, format)
+        "unique_filename": ("%s.%s" % (unique_name, format)) if format else unique_name
     }
 
+
 def app(permission_bit=0):
     """
     应用端访问： app web
-    :param permission_bit: 
-    :return: 
+    :param permission_bit:
+    :return:
     """
+
     def wrap(method):
         @wraps(method)
         def has_role(self, *args, **kwargs):
@@ -132,7 +161,7 @@ def app(permission_bit=0):
             if self.request.headers.get("uid", None):
                 _check_admin(self)
             else:
-                raise errors.MemberNotFound
+                raise errors.ErrorUserNotFound
 
             _check_token(self, permission_bit)
 
@@ -142,6 +171,7 @@ def app(permission_bit=0):
 
     return wrap
 
+
 def admin(permission_bit=0):
     """
     管理后台验证: jtw
@@ -153,21 +183,32 @@ def admin(permission_bit=0):
     def wrap(method):
         @wraps(method)
         def has_role(self, *args, **kwargs):
+            self.uid = self.request.headers.get("uid", 0)
+            if type(self.uid) != int and self.uid.isdigit():
+                self.uid = int(self.uid)
+            self.token = self.request.headers.get("token", "")
+            if permission_bit:
+                # 是否合法请求
+                token_debug = self.application.token_config.get("debug", False)
+                if not token_debug:
+                    _check_token(self, permission_bit)
+
+                # 用户后台
+                if self.request.headers.get("uid", None):
+                    _check_admin(self)
+
+                # 开发者接口方式访问
+                elif self.request.headers.get("appkey", None):
+                    pass
+                # 公司账户访问
+                elif self.request.headers.get("commany", None):
+                    pass
+
             self.params = funts.get_params(self)
-            if self.application.app_config["wsgi"]["logging_debug"] == "debug":
-                logging.warning(self.params)
-
-            # 用户后台
-            if self.request.headers.get("uid", None):
-                _check_admin(self)
-            # 开发者接口方式访问
-            elif self.request.headers.get("appkey", None):
-                pass
-            # 公司账户访问
-            elif self.request.headers.get("commany", None):
-                pass
-
-            _check_token(self, permission_bit)
+            if self.app_config.get("logging_config", {}).get("level", "debug") == "debug":
+                logging.debug(
+                    "请求参数: " + (utils.to_json(utils.check2json(utils.pparams(self.request, params=self.params)))
+                                if hasattr(self, "params") else str(utils.pparams(self.request) or {})))
 
             return method(self, *args, **kwargs)
 
@@ -231,43 +272,39 @@ def api(permission_bit=1):
 
 def _check_admin(self):
     self.is_admin = True
-    self.uid = self.app_key = self.request.headers.get("uid", 0)
-
-    if type(self.uid) != int and self.uid.isdigit():
-        self.uid = int(self.uid)
 
     self.member = self.model.AdminModel.get_admin(self.uid)
     if not self.member:
-        raise errors.MemberNotFound
+        raise errors.ErrorUserNotFound
 
     self.gid = self.member["gid"]
 
+
 def _check_token(self, permission_bit):
-    self.token = self.request.headers.get("token", "")
-    token_debug = self.application.token_config.get("debug", False)
-    if not token_debug:
-        if permission_bit != 0:
-            if not self.uid or not self.token:
+    if permission_bit != 0:
+        if not self.uid or not self.token:
+            raise errors.ErrorTokenInvalid
+
+        jwt = JWT.JwtToken(self.uid, self.application.token_config["secret"],
+                           self.application.token_config["expire"])
+
+        # if self.application.token_config["secret"] in ["******"]:
+        #     return
+
+        try:
+            if not jwt.is_validate(self.token):
                 raise errors.ErrorTokenInvalid
 
-            jwt = JWT.JwtToken(self.uid, self.application.token_config["secret"],
-                               self.application.token_config["expire"])
+            if jwt.is_expire(self.token):
+                raise errors.ErrorTokenExpireInvalid
 
-            # if self.application.token_config["secret"] in ["******"]:
-            #     return
-
-            try:
-                if not jwt.is_validate(self.token):
-                    raise errors.ErrorTokenInvalid
-
-                if jwt.is_expire(self.token):
-                    raise errors.ErrorTokenExpireInvalid
-
-                payload = jwt.decode(self.token)
-                if payload and payload["uid"] != self.uid:
-                    raise errors.ErrorTokenInvalid
-            except Exception as e:
+            payload = jwt.decode(self.token)
+            if payload and payload["uid"] != self.uid:
                 raise errors.ErrorTokenInvalid
+            # 下次请求的token
+            self.set_header("Token", jwt.refresh_token(self.token))
+        except Exception as e:
+            raise errors.ErrorTokenInvalid
 
 
 def verifi_sign(self, token, secret_key):
@@ -490,9 +527,11 @@ def get_ua_client(ua):
     except:
         return 0
 
+
 def tts():
     return time.time() * 1000
 
+
 def get_argument(self):
     """
     ******
