@@ -24,7 +24,7 @@ class UserEvent(BaseEvent):
     @shared_task(ignore_result=False)  # 普通函数装饰为 celery task
     def register(x):
         """
-        seleep时间随机
+        sleep时间随机
         任务多线程并发执行，谁先执行完毕，谁先输出结果
         :use self.application.celery.DefaultEvent.add.delay(111)
         :param x:
