@@ -7,6 +7,26 @@ from celery.utils.log import get_task_logger
 
 logger = get_task_logger(__name__)
 
+"""
+# 例子一： 延迟执行
+eta=datetime.utcnow() + timedelta(seconds=10),  # 在指定的时间运行，这里实现了延迟10秒运行，2022-01-13 09:32:08.643081
+func.apply_async(args=(x, ), eta=eta)
+
+# 例子2：完成后回调
+func.apply_async(args=(11111, ), link=callback.s())
+
+# 例子3：指定队列
+self.celery.Events.send_email.apply_async(
+    args=[
+        user,
+        password
+    ],
+    queue="default",
+    routing_key="default",
+)
+"""
+
+
 @shared_task(ignore_result=False)  # 普通函数装饰为 celery task
 def func(x):
     """
@@ -20,6 +40,17 @@ def func(x):
     logger.info('Adding {0} + {1}'.format(x, "e"))
     return x, n
 
+@shared_task
+def callback(result):
+    """
+    用于回调
+    先执行其他task，成功后，在将其参数传入，调用当前函数
+    example: func.apply_async(args=(11111, ), link=callback.s())
+    :param result:
+    :return:
+    """
+    print(f'My result was {result}')
+
 
 class DefaultEvent(BaseEvent):
     queue = "for_task_A"
@@ -83,8 +114,8 @@ class DefaultEvent(BaseEvent):
                 bind=True,                            # True时，task对象self，会作为第一个参数自动传入，可以使用任务对象的属性。self.xxx。当设置以下参数时，必须绑定
                 name="tasks.test_retry",                   # 名称，默认用函数名
                 queue='for_task_A',                   # 指定队列,优先级高于配置文件中的CELERY_ROUTES
-                countdown=10,                         # 延迟10s执行
-                max_retries=3,                        # 错误重试次数，https://docs.celeryproject.org/en/master/userguide/tasks.html#automatic-retry-for-known-exceptions
+                countdown=10,                         # 10s后重试
+                max_retries=3,                        # 重试次数，https://docs.celeryproject.org/en/master/userguide/tasks.html#automatic-retry-for-known-exceptions
                 default_retry_delay=3,                # 默认重试的间隔时间，优先级低于countdown属性
                 # autoretry_for=(ReadTimeout,),       # 添加要自动重试的异常，如果所有异常都需要重试可以写Exception，默认不写所有异常都重试。，也可以通过try..execpt 手动调用重试函数
                 soft_time_limit=5,                    # 任务最大执行时间
@@ -114,7 +145,7 @@ class DefaultEvent(BaseEvent):
         bind=True,  # True时，task对象self，会作为第一个参数自动传入，可以使用任务对象的属性。self.xxx。当设置以下参数时，必须绑定
         name="tasks.test_retry2",  # 名称，默认用函数名
         queue='for_task_A',  # 指定队列,优先级高于配置文件中的CELERY_ROUTES
-        countdown=10,  # 延迟10s执行
+        countdown=10,  # 10s后重试
         max_retries=3,
         # 错误重试次数，https://docs.celeryproject.org/en/master/userguide/tasks.html#automatic-retry-for-known-exceptions
         default_retry_delay=3,  # 默认重试的间隔时间，优先级低于countdown属性
