@@ -18,12 +18,14 @@ def __create_spaces(lvl):
 def __print(obj,end='\n'):
     if isinstance(obj,(str, int, float)):
         sys.stdout.write(str(obj)+end)
+    elif obj is None:
+        sys.stdout.write("None" + end)
     else:
         print(obj)
         sys.stdout.write(end)
 
 def cprint(obj,lvl=0,indict=False,islast=True):
-    lvl = lvl + 1 
+    lvl = lvl + 1
     spaces = __create_spaces(lvl)
     index = 0
 
@@ -38,11 +40,6 @@ def cprint(obj,lvl=0,indict=False,islast=True):
                 cprint(item,lvl)
             index = index + 1
         __print(spaces + ']',end='')
-        if islast:
-            __print('')
-        else:
-            __print(',')
-
     elif isinstance(obj,tuple):
         if not indict:
             __print(spaces,end='')
@@ -54,11 +51,6 @@ def cprint(obj,lvl=0,indict=False,islast=True):
                 cprint(item,lvl)
             index = index + 1
         __print(spaces + ')',end='')
-        if islast:
-            __print('')
-        else:
-            __print(',')
-
     elif isinstance(obj,set):
         if not indict:
             __print(spaces,end='')
@@ -70,11 +62,6 @@ def cprint(obj,lvl=0,indict=False,islast=True):
                 cprint(item,lvl)
             index = index + 1
         __print(spaces + ')',end='')
-        if islast:
-            __print('')
-        else:
-            __print(',')
-
     elif isinstance(obj,dict):
         __print(spaces + '{')
         for key in obj:
@@ -85,21 +72,19 @@ def cprint(obj,lvl=0,indict=False,islast=True):
                 cprint(obj[key],lvl,indict=True)
             index = index + 1
         __print(spaces + '}',end='')
-        if islast:
-            __print('')
-        else:
-            __print(',')
-
+    elif obj is None:
+        __print(obj, end='')
     else:
         if isinstance(obj, str):
             obj = '"' + obj + '"'
         if not indict:
             __print(spaces,end='')
         __print(obj,end='')
-        if islast:
-            __print('')
-        else:
-            __print(',')
+
+    if islast:
+        __print('')
+    else:
+        __print(',')
 
 
 
