@@ -140,11 +140,35 @@ class ServicesFindet(object):
         self.__mount_attribute("beanstalk", app)
         return app
 
+    def import_websocket(self, config):
+        f = config.get("websocket_config")
+        if not f:
+            return
+        from .singleton import WebScoketCon
+        from lcyframe.libs.websocket_route import Events
+
+        p = utils.fix_path(os.path.join(config["ROOT"], f.get("workers_dir", "works/websocket")))
+        if os.path.exists(p) and not f.get("workers_dir"):
+            f["workers_dir"] = ["works/websocket"]
+
+        app = WebScoketCon.get_instance(**f)
+        setattr(Events, "websocket", app)   # Events.websocket
+        self._import_websocket_worker(app, config["ROOT"], f["workers_dir"], Events)
+        self.__mount_attribute("websocket", app)
+        return app
+
     def import_mob(self, config):
-        f = config.get("mob_config")
+        f = config.get("sms_config")
         if f:
-            from .singleton import MobCon
-            self.__mount_attribute("mob", MobCon.get_connection(**f))
+            from .singleton import SMSCon
+            self.__mount_attribute("sms", SMSCon.get_connection(**f))
+            return True
+
+    def import_smtp(self, config):
+        f = config.get("smtp_config")
+        if f:
+            from .singleton import SmtpCon
+            self.__mount_attribute("smtp", SmtpCon.get_connection(**f))
             return True
 
     def import_qiniu(self, config):
@@ -382,6 +406,65 @@ class ServicesFindet(object):
         app.workers = workers
         return app
 
+    def _import_websocket_worker(self, app, root_path, workers_dir, Events):
+        """
+        register websocket tasks
+        :return:
+        """
+        from lcyframe.libs.websocket_route import WebSocketRoute, Agent
+        workers = WebSocketRoute.get_workers(root_path, workers_dir)
+        for func_name, objs in workers.items():
+            if not hasattr(objs, "from_route"):
+                continue
+
+            if hasattr(Events, func_name):
+                raise Exception("websocket works exists same events：%s" % func_name)
+
+            # setattr(Events, func_name, object)
+
+            # setattr(x, func_name, type(func_name, (Events,), {"event_name": func_name})())
+
+            # x = type(func_name, (Events,), {})()
+            # setattr(Events, func_name, getattr(type(func_name, (Events,), {})(), func_name))
+            # setattr(Events, func_name, getattr(Events(), func_name))
+            setattr(Events, func_name, Agent(Events.websocket, func_name))
+            logging.debug("websocket task class [%s] register success!" % func_name)
+
+        setattr(app, Events.__name__, Events)
+        return app
+
+        workers_dir = [workers_dir] if not isinstance(workers_dir, (list, tuple)) else workers_dir
+        for work in workers_dir:
+            for root, dirs, files in os.walk(utils.fix_path(os.path.join(root_path, work))):
+                for file in files:
+                    if file.startswith("__"):
+                        continue
+
+                    if file.endswith(".pyc"):
+                        continue
+
+                    if not file.endswith(".py"):
+                        continue
+
+                    model_name = self.fix_module_path(root.replace(root_path, "")) + "." + file.rstrip(".py")
+                    objs = __import__(model_name, fromlist=["*"])
+                    for p in dir(objs):
+                        if p.startswith("__"):
+                            continue
+
+                        if not hasattr(getattr(objs, p), "from_route"):
+                            continue
+
+                        if hasattr(Events, p):
+                            raise Exception("exists same attribute：%s" % p)
+
+                        logging.debug("websocket task [%s] register success!" % p)
+
+                        setattr(Events, p, getattr(objs, p))
+
+        setattr(app, Events.__name__, Events)
+        return app
+
     def fix_module_path(self, module_path):
         module_path = utils.fix_path(module_path)
         module_path = module_path.lstrip("/").replace("/", ".").replace("//", ".").replace("/", ".")
